import { ChevronLeft } from "lucide-react";

import { CountdownTimer } from "@/components/shared/countdown-timer";
import { ProductWithSalesItem } from "@/components/shared/product-with-sales-item";
import { Link, Locale } from "@/i18n/routing";
import { cn } from "@/lib/utils";
import { getSalesData } from "@/utils/get-fake-data";

interface SalesProps {
	locale: Locale;
}

export default async function Sales({ locale }: SalesProps) {
	const data = await getSalesData();
	const isRTL = locale === "ar";

	return (
		<section className="container mx-auto max-w-7xl px-4 py-16" dir={!isRTL ? "rtl" : "ltr"}>
			{/* Header */}
			<div
				className={cn(
					"mb-8 flex items-center justify-between",
				)}
				dir={!isRTL ? "rtl" : "ltr"}
			>
				<Link
					href="/"
					className={cn(
						"flex items-center gap-2 text-[#2895C8] transition-colors hover:text-[#2895C8]/80",
						!isRTL && "flex-row-reverse"
					)}
				>
					<ChevronLeft
						className={cn("h-6 w-6", !isRTL && "rotate-180 transform")}
					/>
					<span className="text-md">{data.header.viewAll?.[locale]}</span>
				</Link>
				<div
					className={cn("flex items-center gap-4", isRTL && "flex-row-reverse")}
				>
					<CountdownTimer
						endTime={data.header.endTime}
						locale={locale}
						className="rounded-2xl bg-[#2895C8] px-4 py-1 text-white"
					/>
					<h2 className="text-2xl text-gray-900">
						{data.header.title?.[locale]}
					</h2>
				</div>
			</div>
			{/* Products Grid */}
			<div className="grid gap-4 overflow-hidden md:grid-cols-2 xl:grid-cols-3">
				{data.products?.map((product) => (
					<ProductWithSalesItem key={product.id} {...product} locale={locale} />
				))}
			</div>
		</section>
	);
}
